@@ -27,22 +27,19 @@ class RemoveCommand(BaseCommand):
         project.core.ui.echo("Virtualenvs created with this project:")
         for ident, venv in iter_venvs(project):
             if ident == options.env:
-                if options.yes or termui.confirm(
-                    f"[yellow]Will remove: [green]{venv}[/], continue?", default=True
-                ):
+                if options.yes or termui.confirm(f"[warning]Will remove: [success]{venv}[/], continue?", default=True):
                     shutil.rmtree(venv)
                     if (
                         project.project_config.get("python.path")
-                        and Path(project.project_config["python.path"]).parent.parent
-                        == venv
+                        and Path(project.project_config["python.path"]).parent.parent == venv
                     ):
                         del project.project_config["python.path"]
                     project.core.ui.echo("Removed successfully!")
                 break
         else:
             project.core.ui.echo(
-                f"No virtualenv with key [green]{options.env}[/] is found",
-                style="yellow",
+                f"No virtualenv with key [success]{options.env}[/] is found",
+                style="warning",
                 err=True,
             )
             raise SystemExit(1)
