@@ -4,11 +4,9 @@ import functools
 import operator
 import os
 import re
-from argparse import Namespace
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Mapping, cast
+from typing import TYPE_CHECKING, Any, Iterable, Mapping, cast
 
-from pdm._types import RequirementDict, Source
 from pdm.compat import tomllib
 from pdm.formats.base import (
     MetaConverter,
@@ -23,12 +21,17 @@ from pdm.models.requirements import Requirement
 from pdm.models.specifiers import PySpecSet
 
 if TYPE_CHECKING:
+    from argparse import Namespace
+
+    from pdm._types import RequirementDict, Source
     from pdm.project.core import Project
 
 from pdm.utils import cd
 
 
 def check_fingerprint(project: Project | None, filename: Path | str) -> bool:
+    if Path(filename).name != "pyproject.toml":
+        return False
     with open(filename, "rb") as fp:
         try:
             data = tomllib.load(fp)
@@ -43,17 +46,17 @@ VERSION_RE = re.compile(r"([^\d\s]*)\s*(\d.*?)\s*(?=,|$)")
 
 def _convert_specifier(version: str) -> str:
     parts = []
-    for op, version in VERSION_RE.findall(str(version)):
+    for op, ver in VERSION_RE.findall(str(version)):
         if op == "~":
             op += "="
         elif op == "^":
-            major, *vparts = version.split(".")
+            major, *vparts = ver.split(".")
             next_major = ".".join([str(int(major) + 1)] + ["0"] * len(vparts))
-            parts.append(f">={version},<{next_major}")
+            parts.append(f">={ver},<{next_major}")
             continue
         elif not op:
             op = "=="
-        parts.append(f"{op}{version}")
+        parts.append(f"{op}{ver}")
     return ",".join(parts)
 
 
@@ -64,31 +67,30 @@ def _convert_python(python: str) -> PySpecSet:
     return functools.reduce(operator.or_, parts)
 
 
-def _convert_req(name: str, req_dict: RequirementDict) -> str:
-    if not getattr(req_dict, "items", None):
-        assert isinstance(req_dict, str)
-        return Requirement.from_req_dict(name, _convert_specifier(req_dict)).as_line()
-    assert isinstance(req_dict, dict)
-    req_dict = dict(req_dict)
-    req_dict.pop("optional", None)  # Ignore the 'optional' key
-    if "version" in req_dict:
-        req_dict["version"] = _convert_specifier(str(req_dict["version"]))
-    markers: list[Marker] = []
-    if "markers" in req_dict:
-        markers.append(Marker(req_dict.pop("markers")))  # type: ignore
-    if "python" in req_dict:
-        markers.append(
-            Marker(_convert_python(str(req_dict.pop("python"))).as_marker_string())
-        )
-    if markers:
-        req_dict["marker"] = str(functools.reduce(operator.and_, markers)).replace(
-            '"', "'"
-        )
-    if "rev" in req_dict or "branch" in req_dict or "tag" in req_dict:
-        req_dict["ref"] = req_dict.pop(
-            "rev", req_dict.pop("tag", req_dict.pop("branch", None))  # type: ignore
-        )
-    return Requirement.from_req_dict(name, req_dict).as_line()
+def _convert_req(name: str, req_dict: RequirementDict | list[RequirementDict]) -> Iterable[str]:
+    if isinstance(req_dict, list):
+        for req in req_dict:
+            yield from _convert_req(name, req)
+    elif isinstance(req_dict, str):
+        yield Requirement.from_req_dict(name, _convert_specifier(req_dict)).as_line()
+    else:
+        assert isinstance(req_dict, dict)
+        req_dict = dict(req_dict)
+        req_dict.pop("optional", None)  # Ignore the 'optional' key
+        if "version" in req_dict:
+            req_dict["version"] = _convert_specifier(str(req_dict["version"]))
+        markers: list[Marker] = []
+        if "markers" in req_dict:
+            markers.append(Marker(req_dict.pop("markers")))  # type: ignore[arg-type]
+        if "python" in req_dict:
+            markers.append(Marker(_convert_python(str(req_dict.pop("python"))).as_marker_string()))
+        if markers:
+            req_dict["marker"] = str(functools.reduce(operator.and_, markers)).replace('"', "'")
+        if "rev" in req_dict or "branch" in req_dict or "tag" in req_dict:
+            req_dict["ref"] = req_dict.pop(
+                "rev", req_dict.pop("tag", req_dict.pop("branch", None))  # type: ignore[arg-type]
+            )
+        yield Requirement.from_req_dict(name, req_dict).as_line()
 
 
 class PoetryMetaConverter(MetaConverter):
@@ -121,9 +123,7 @@ class PoetryMetaConverter(MetaConverter):
         return rv
 
     @convert_from("plugins", name="entry-points")
-    def entry_points(
-        self, value: dict[str, dict[str, str]]
-    ) -> dict[str, dict[str, str]]:
+    def entry_points(self, value: dict[str, dict[str, str]]) -> dict[str, dict[str, str]]:
         return value
 
     @convert_from()
@@ -131,27 +131,21 @@ class PoetryMetaConverter(MetaConverter):
         rv = []
         value, extras = dict(source["dependencies"]), source.pop("extras", {})
         for key, req_dict in value.items():
-            optional = getattr(req_dict, "items", None) and req_dict.pop(
-                "optional", False
-            )
-            req = _convert_req(key, req_dict)
-            if optional:
-                extra = next((k for k, v in extras.items() if key in v), None)
-                if extra:
-                    self._data.setdefault("optional-dependencies", {}).setdefault(
-                        extra, []
-                    ).append(req)
-            else:
-                rv.append(req)
+            optional = getattr(req_dict, "items", None) and req_dict.pop("optional", False)
+            for req in _convert_req(key, req_dict):
+                if optional:
+                    extra = next((k for k, v in extras.items() if key in v), None)
+                    if extra:
+                        self._data.setdefault("optional-dependencies", {}).setdefault(extra, []).append(req)
+                else:
+                    rv.append(req)
         del source["dependencies"]
         return make_array(rv, True)
 
     @convert_from("dev-dependencies")
     def dev_dependencies(self, value: dict) -> None:
         self.settings["dev-dependencies"] = {
-            "dev": make_array(
-                [_convert_req(key, req) for key, req in value.items()], True
-            ),
+            "dev": make_array([r for key, req in value.items() for r in _convert_req(key, req)], True),
         }
         raise Unset()
 
@@ -180,9 +174,7 @@ class PoetryMetaConverter(MetaConverter):
             if "generate-setup-file" in value:
                 run_setuptools = cast(bool, value["generate-setup-file"])
             value = value["script"]
-        self.settings.setdefault("build", {}).update(
-            {"setup-script": value, "run-setuptools": run_setuptools}
-        )
+        self.settings.setdefault("build", {}).update({"setup-script": value, "run-setuptools": run_setuptools})
         raise Unset()
 
     @convert_from("source")
@@ -204,9 +196,7 @@ def convert(
     options: Namespace | None,
 ) -> tuple[Mapping[str, Any], Mapping[str, Any]]:
     with open(filename, "rb") as fp, cd(os.path.dirname(os.path.abspath(filename))):
-        converter = PoetryMetaConverter(
-            tomllib.load(fp)["tool"]["poetry"], project.core.ui if project else None
-        )
+        converter = PoetryMetaConverter(tomllib.load(fp)["tool"]["poetry"], project.core.ui if project else None)
         return converter.convert()
 
 
