@@ -1,9 +1,10 @@
 from __future__ import annotations
 
 import json
+import re
 from functools import lru_cache
 from operator import attrgetter
-from typing import Any, Iterable, cast
+from typing import Any, Iterable, Match, cast
 
 from packaging.specifiers import InvalidSpecifier, SpecifierSet
 
@@ -27,6 +28,29 @@ def get_specifier(version_str: SpecifierSet | str) -> SpecifierSet:
     return SpecifierSet(version_str)
 
 
+_legacy_specifier_re = re.compile(r"(==|!=|<=|>=|<|>)(\s*)([^,;\s)]*)")
+
+
+@lru_cache()
+def fix_legacy_specifier(specifier: str) -> str:
+    """Since packaging 22.0, legacy specifiers like '>=4.*' are no longer
+    supported. We try to normalize them to the new format.
+    """
+
+    def fix_wildcard(match: Match[str]) -> str:
+        operator, _, version = match.groups()
+        if ".*" not in version or operator in ("==", "!="):
+            return match.group(0)
+        version = version.replace(".*", ".0")
+        if operator in ("<", "<="):  # <4.* and <=4.* are equivalent to <4.0
+            operator = "<"
+        elif operator in (">", ">="):  # >4.* and >=4.* are equivalent to >=4.0
+            operator = ">="
+        return f"{operator}{version}"
+
+    return _legacy_specifier_re.sub(fix_wildcard, specifier)
+
+
 def _normalize_op_specifier(op: str, version_str: str) -> tuple[str, Version]:
     version = Version(version_str)
     if version.is_wildcard:
@@ -58,17 +82,17 @@ class PySpecSet(SpecifierSet):
     PY_MAX_MINOR_VERSION = _read_max_versions()
     MAX_MAJOR_VERSION = max(PY_MAX_MINOR_VERSION)[:1].bump()
 
-    def __init__(self, version_str: str = "", analyze: bool = True) -> None:
-        if version_str == "*":
-            version_str = ""
+    def __init__(self, specifiers: str = "", analyze: bool = True) -> None:
+        if specifiers == "*":
+            specifiers = ""
         try:
-            super().__init__(version_str)
+            super().__init__(fix_legacy_specifier(specifiers))
         except InvalidSpecifier as e:
             raise InvalidPyVersion(str(e)) from e
         self._lower_bound = Version.MIN
         self._upper_bound = Version.MAX
         self._excludes: list[Version] = []
-        if version_str and analyze:
+        if specifiers and analyze:
             self._analyze_specifiers()
 
     def _analyze_specifiers(self) -> None:
@@ -84,13 +108,9 @@ class PySpecSet(SpecifierSet):
             if op == "!=":
                 excludes.add(version)
             elif op[0] == ">":
-                lower_bound = max(
-                    lower_bound, version if op == ">=" else version.bump()
-                )
+                lower_bound = max(lower_bound, version if op == ">=" else version.bump())
             elif op[0] == "<":
-                upper_bound = min(
-                    upper_bound, version.bump() if op == "<=" else version
-                )
+                upper_bound = min(upper_bound, version.bump() if op == "<=" else version)
             elif op == "~=":
                 new_lower = version.complete()
                 new_upper = version.bump(-2)
@@ -110,15 +130,12 @@ class PySpecSet(SpecifierSet):
         excludes: Iterable[Version],
     ) -> tuple[Version, Version, list[Version]]:
         sorted_excludes = sorted(excludes)
-        wildcard_excludes = {
-            version[:-1] for version in sorted_excludes if version.is_wildcard
-        }
+        wildcard_excludes = {version[:-1] for version in sorted_excludes if version.is_wildcard}
         # Remove versions that are already excluded by another wildcard exclude.
         sorted_excludes = [
             version
             for version in sorted_excludes
-            if version.is_wildcard
-            or not any(version.startswith(wv) for wv in wildcard_excludes)
+            if version.is_wildcard or not any(version.startswith(wv) for wv in wildcard_excludes)
         ]
 
         if lower == Version.MIN and upper == Version.MAX:
@@ -175,9 +192,7 @@ class PySpecSet(SpecifierSet):
 
         return lower, upper, sorted_excludes
 
-    def _rearrange(
-        self, lower_bound: Version, upper_bound: Version, excludes: Iterable[Version]
-    ) -> None:
+    def _rearrange(self, lower_bound: Version, upper_bound: Version, excludes: Iterable[Version]) -> None:
         """Rearrange the version bounds with the given inputs."""
         (
             self._lower_bound,
@@ -210,11 +225,7 @@ class PySpecSet(SpecifierSet):
         """Return True if the specifierset accepts all versions."""
         if self.is_impossible:
             return False
-        return (
-            self._lower_bound == Version.MIN
-            and self._upper_bound == Version.MAX
-            and not self._excludes
-        )
+        return self._lower_bound == Version.MIN and self._upper_bound == Version.MAX and not self._excludes
 
     def __bool__(self) -> bool:
         return not self.is_allow_all
@@ -280,15 +291,11 @@ class PySpecSet(SpecifierSet):
         lower = left._lower_bound
         upper = max(left._upper_bound, right._upper_bound)
         if right._lower_bound > left._upper_bound:  # two ranges has no overlap
-            excludes.update(
-                self._populate_version_range(left._upper_bound, right._lower_bound)
-            )
+            excludes.update(self._populate_version_range(left._upper_bound, right._lower_bound))
         rv._rearrange(lower, upper, excludes)
         return rv
 
-    def _populate_version_range(
-        self, lower: Version, upper: Version
-    ) -> Iterable[Version]:
+    def _populate_version_range(self, lower: Version, upper: Version) -> Iterable[Version]:
         """Expand the version range to a collection of versions to exclude,
         taking the released python versions into consideration.
         """
@@ -306,10 +313,7 @@ class PySpecSet(SpecifierSet):
                 if cur <= upper:  # It is still within the range
                     yield prev[:2].complete("*")  # Exclude X.Y.*
                     prev = (
-                        prev.bump(0)
-                        if cur.is_py2
-                        and cast(int, cur[1]) > self.PY_MAX_MINOR_VERSION[cur[:1]]
-                        else cur
+                        prev.bump(0) if cur.is_py2 and cast(int, cur[1]) > self.PY_MAX_MINOR_VERSION[cur[:1]] else cur
                     )  # If prev is 2.7, next is 3.0, otherwise next is X.Y+1.0
                     continue
                 while prev < upper:
@@ -323,12 +327,7 @@ class PySpecSet(SpecifierSet):
                 current_max = self.PY_MAX_MINOR_VERSION[prev[:2]]
                 for z in range(cast(int, prev[2]), current_max + 1):
                     yield prev[:2].complete(z)
-                prev = (
-                    prev.bump(0)
-                    if cur.is_py2
-                    and cast(int, cur[1]) > self.PY_MAX_MINOR_VERSION[cur[:1]]
-                    else cur
-                )
+                prev = prev.bump(0) if cur.is_py2 and cast(int, cur[1]) > self.PY_MAX_MINOR_VERSION[cur[:1]] else cur
             else:  # Produce each version from X.Y.Z to X.Y.W
                 while prev < upper:
                     yield prev
@@ -346,19 +345,10 @@ class PySpecSet(SpecifierSet):
             # XXX: narrow down the upper bound to ``MAX_MAJOR_VERSION``
             # So that `>=3.6,<4.0` is considered a superset of `>=3.7`, see issues/66
             other._upper_bound = self.MAX_MAJOR_VERSION
-        lower, upper, excludes = self._merge_bounds_and_excludes(
-            other._lower_bound, other._upper_bound, self._excludes
-        )
-        if (
-            self._lower_bound > other._lower_bound
-            or self._upper_bound < other._upper_bound
-        ):
+        lower, upper, excludes = self._merge_bounds_and_excludes(other._lower_bound, other._upper_bound, self._excludes)
+        if self._lower_bound > other._lower_bound or self._upper_bound < other._upper_bound:
             return False
-        return (
-            lower <= other._lower_bound
-            and upper >= other._upper_bound
-            and set(excludes) <= set(other._excludes)
-        )
+        return lower <= other._lower_bound and upper >= other._upper_bound and set(excludes) <= set(other._excludes)
 
     @lru_cache()
     def is_subset(self, other: str | SpecifierSet) -> bool:
@@ -370,19 +360,10 @@ class PySpecSet(SpecifierSet):
             other._upper_bound = Version.MAX
         if other.is_allow_all:
             return True
-        lower, upper, excludes = self._merge_bounds_and_excludes(
-            self._lower_bound, self._upper_bound, other._excludes
-        )
-        if (
-            self._lower_bound < other._lower_bound
-            or self._upper_bound > other._upper_bound
-        ):
+        lower, upper, excludes = self._merge_bounds_and_excludes(self._lower_bound, self._upper_bound, other._excludes)
+        if self._lower_bound < other._lower_bound or self._upper_bound > other._upper_bound:
             return False
-        return (
-            lower <= self._lower_bound
-            and upper >= self._upper_bound
-            and set(self._excludes) >= set(excludes)
-        )
+        return lower <= self._lower_bound and upper >= self._upper_bound and set(self._excludes) >= set(excludes)
 
     def as_marker_string(self) -> str:
         if self.is_allow_all:
@@ -407,15 +388,9 @@ class PySpecSet(SpecifierSet):
             else:
                 result.append(f"{key}{op}{version!r}")
         if excludes:
-            result.append(
-                "python_version not in {!r}".format(", ".join(sorted(excludes)))
-            )
+            result.append("python_version not in {!r}".format(", ".join(sorted(excludes))))
         if full_excludes:
-            result.append(
-                "python_full_version not in {!r}".format(
-                    ", ".join(sorted(full_excludes))
-                )
-            )
+            result.append("python_full_version not in {!r}".format(", ".join(sorted(full_excludes))))
         return " and ".join(result)
 
     def supports_py2(self) -> bool:
@@ -428,7 +403,7 @@ class ImpossiblePySpecSet(PySpecSet):
     """
 
     def __init__(self, version_str: str = "", analyze: bool = True) -> None:
-        super().__init__(version_str=version_str, analyze=False)
+        super().__init__(specifiers=version_str, analyze=False)
         # Make sure the spec set is impossible
         self._lower_bound = Version.MAX
         self._upper_bound = Version.MIN
